@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2014 Andrew M. Bishop
+ This file Copyright 2008-2015 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -22,10 +22,11 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <string.h>
 #include <errno.h>
 
+#include "version.h"
+
 #include "types.h"
 #include "ways.h"
 
@@ -70,7 +71,7 @@ int main(int argc,char** argv)
  WaysX      *OSMWays;
  RelationsX *OSMRelations;
  ErrorLogsX *OSMErrorLogs;
- char       *dirname=NULL,*prefix=NULL,*tagging="fixme.xml",*errorlog="fixme.log";
+ char       *dirname=NULL,*prefix=NULL,*tagging=NULL;
  int         option_keep=1;
  int         option_filenames=0;
  int         arg;
@@ -81,7 +82,9 @@ int main(int argc,char** argv)
 
  for(arg=1;arg<argc;arg++)
    {
-    if(!strcmp(argv[arg],"--help"))
+    if(!strcmp(argv[arg],"--version"))
+       print_usage(-1,NULL,NULL);
+    else if(!strcmp(argv[arg],"--help"))
        print_usage(1,NULL,NULL);
     else if(!strncmp(argv[arg],"--dir=",6))
        dirname=&argv[arg][6];
@@ -138,11 +141,11 @@ int main(int argc,char** argv)
    }
  else
    {
-    if(ExistsFile(FileName(dirname,prefix,"tagging.xml")))
-       tagging=FileName(dirname,prefix,"tagging.xml");
-    else
+    tagging=FileName(dirname,prefix,"fixme.xml");
+
+    if(!ExistsFile(tagging))
       {
-       fprintf(stderr,"Error: The '--tagging' option was not used and the default 'tagging.xml' does not exist.\n");
+       fprintf(stderr,"Error: The '--tagging' option was not used and the default 'fixme.xml' does not exist.\n");
        exit(EXIT_FAILURE);
       }
    }
@@ -163,8 +166,7 @@ int main(int argc,char** argv)
 
  /* Create the error log file */
 
- if(errorlog)
-    open_errorlog(FileName(dirname,prefix,errorlog),0,option_keep);
+ open_errorlog(FileName(dirname,prefix,"fixme.log"),0,option_keep);
 
  /* Parse the file */
 
@@ -281,7 +283,7 @@ int main(int argc,char** argv)
 /*++++++++++++++++++++++++++++++++++++++
   Print out the usage information.
 
-  int detail The level of detail to use - 0 = low, 1 = high.
+  int detail The level of detail to use: -1 = just version number, 0 = low detail, 1 = full details.
 
   const char *argerr The argument that gave the error (if there is one).
 
@@ -290,43 +292,56 @@ int main(int argc,char** argv)
 
 static void print_usage(int detail,const char *argerr,const char *err)
 {
- fprintf(stderr,
-         "Usage: fixme-finder [--help]\n"
-         "                    [--dir=<dirname>]\n"
+ if(detail<0)
+   {
+    fprintf(stderr,
+            "Routino version " ROUTINO_VERSION " " ROUTINO_URL ".\n"
+            );
+   }
+
+ if(detail>=0)
+   {
+    fprintf(stderr,
+            "Usage: fixme-finder [--version]\n"
+            "                    [--help]\n"
+            "                    [--dir=<dirname>]\n"
 #if defined(USE_PTHREADS) && USE_PTHREADS
-         "                    [--sort-ram-size=<size>] [--sort-threads=<number>]\n"
+            "                    [--sort-ram-size=<size>] [--sort-threads=<number>]\n"
 #else
-         "                    [--sort-ram-size=<size>]\n"
+            "                    [--sort-ram-size=<size>]\n"
 #endif
-         "                    [--tmpdir=<dirname>]\n"
-         "                    [--tagging=<filename>]\n"
-         "                    [--loggable] [--logtime] [--logmemory]\n"
-         "                    [<filename.osm> ...\n"
-         "                     | <filename.pbf> ...\n"
-         "                     | <filename.o5m> ..."
+            "                    [--tmpdir=<dirname>]\n"
+            "                    [--tagging=<filename>]\n"
+            "                    [--loggable] [--logtime] [--logmemory]\n"
+            "                    [<filename.osm> ...\n"
+            "                     | <filename.pbf> ...\n"
+            "                     | <filename.o5m> ..."
 #if defined(USE_BZIP2) && USE_BZIP2
-         "\n                     | <filename.(osm|o5m).bz2> ..."
+            "\n                     | <filename.(osm|o5m).bz2> ..."
 #endif
 #if defined(USE_GZIP) && USE_GZIP
-         "\n                     | <filename.(osm|o5m).gz> ..."
+            "\n                     | <filename.(osm|o5m).gz> ..."
 #endif
 #if defined(USE_XZ) && USE_XZ
-         "\n                     | <filename.(osm|o5m).xz> ..."
+            "\n                     | <filename.(osm|o5m).xz> ..."
 #endif
-         "]\n");
+            "]\n");
 
- if(argerr)
+    if(argerr)
+       fprintf(stderr,
+               "\n"
+               "Error with command line parameter: %s\n",argerr);
+
+    if(err)
+       fprintf(stderr,
+               "\n"
+               "Error: %s\n",err);
+   }
+
+ if(detail==1)
     fprintf(stderr,
             "\n"
-            "Error with command line parameter: %s\n",argerr);
-
- if(err)
-    fprintf(stderr,
-            "\n"
-            "Error: %s\n",err);
-
- if(detail)
-    fprintf(stderr,
+            "--version                 Print the version of Routino.\n"
             "\n"
             "--help                    Prints this information.\n"
             "\n"
