@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2013 Andrew M. Bishop
+ This file Copyright 2008-2015 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -26,15 +26,41 @@
 /* If your system does not have the pread() and pwrite() system calls then you
  * will need to change this line to the value 0 so that seek() and
  * read()/write() are used instead of pread()/pwrite(). */
+
+#if defined(_MSC_VER) || defined(__MINGW32__)
+#define HAVE_PREAD_PWRITE 0
+#else
 #define HAVE_PREAD_PWRITE 1
+#endif
 
-
+#if defined(_MSC_VER)
+#include <io.h>
+#include <basetsd.h>
+#define read(fd,address,length)  _read(fd,address,(unsigned int)(length))
+#define write(fd,address,length) _write(fd,address,(unsigned int)(length))
+#define ssize_t SSIZE_T
+#else
 #include <unistd.h>
+#endif
+
+#if defined(_MSC_VER) || defined(__MINGW32__)
+#undef lseek
+#define lseek _lseeki64
+#endif
+
 #include <sys/types.h>
+#include <inttypes.h>
 
 #include "logging.h"
 
 
+/* Types */
+
+/*+ A 64-bit file offset since a 32-bit off_t (which is signed) is smaller than a
+    32-bit size_t (which is unsigned) that can be writtento or read from a file. +*/
+typedef int64_t offset_t;
+
+
 /* Functions in files.c */
 
 char *FileName(const char *dirname,const char *prefix, const char *name);
@@ -54,11 +80,13 @@ int OpenFileBufferedAppend(const char *filename);
 
 int ReOpenFileBuffered(const char *filename);
 
+int ReplaceFileBuffered(const char *filename,int *oldfd);
+
 int WriteFileBuffered(int fd,const void *address,size_t length);
 int ReadFileBuffered(int fd,void *address,size_t length);
 
-int SeekFileBuffered(int fd,off_t position);
-int SkipFileBuffered(int fd,off_t skip);
+int SeekFileBuffered(int fd,offset_t position);
+int SkipFileBuffered(int fd,offset_t skip);
 
 int CloseFileBuffered(int fd);
 
@@ -66,7 +94,8 @@ int OpenFile(const char *filename);
 
 void CloseFile(int fd);
 
-off_t SizeFile(const char *filename);
+offset_t SizeFile(const char *filename);
+offset_t SizeFileFD(int fd);
 int ExistsFile(const char *filename);
 
 int DeleteFile(const char *filename);
@@ -75,8 +104,8 @@ int RenameFile(const char *oldfilename,const char *newfilename);
 
 /* Functions in files.h */
 
-static inline int SlimReplace(int fd,const void *address,size_t length,off_t position);
-static inline int SlimFetch(int fd,void *address,size_t length,off_t position);
+static inline int SlimReplace(int fd,const void *address,size_t length,offset_t position);
+static inline int SlimFetch(int fd,void *address,size_t length,offset_t position);
 
 
 /* Inline the frequently called functions */
@@ -92,10 +121,10 @@ static inline int SlimFetch(int fd,void *address,size_t length,off_t position);
 
   size_t length The length of data to write.
 
-  off_t position The position in the file to seek to.
+  offset_t position The position in the file to seek to.
   ++++++++++++++++++++++++++++++++++++++*/
 
-static inline int SlimReplace(int fd,const void *address,size_t length,off_t position)
+static inline int SlimReplace(int fd,const void *address,size_t length,offset_t position)
 {
  /* Seek and write the data */
 
@@ -109,7 +138,7 @@ static inline int SlimReplace(int fd,const void *address,size_t length,off_t pos
  if(lseek(fd,position,SEEK_SET)!=position)
     return(-1);
 
- if(write(fd,address,length)!=length)
+ if(write(fd,address,length)!=(ssize_t)length)
     return(-1);
 
 #endif
@@ -129,10 +158,10 @@ static inline int SlimReplace(int fd,const void *address,size_t length,off_t pos
 
   size_t length The length of data to read.
 
-  off_t position The position in the file to seek to.
+  offset_t position The position in the file to seek to.
   ++++++++++++++++++++++++++++++++++++++*/
 
-static inline int SlimFetch(int fd,void *address,size_t length,off_t position)
+static inline int SlimFetch(int fd,void *address,size_t length,offset_t position)
 {
  /* Seek and read the data */
 
@@ -146,7 +175,7 @@ static inline int SlimFetch(int fd,void *address,size_t length,off_t position)
  if(lseek(fd,position,SEEK_SET)!=position)
     return(-1);
 
- if(read(fd,address,length)!=length)
+ if(read(fd,address,length)!=(ssize_t)length)
     return(-1);
 
 #endif
