@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2013 Andrew M. Bishop
+ This file Copyright 2008-2015 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -24,7 +24,6 @@
 #define LOGGING_H    /*+ To stop multiple inclusions. +*/
 
 #include <stdio.h>
-#include <sys/time.h>
 
 #include "typesx.h"
 
@@ -47,6 +46,7 @@ typedef struct _ErrorLogObject
 
 extern int option_loggable;
 extern int option_logtime;
+extern int option_logmemory;
 
 
 /* Runtime progress logging functions in logging.c */
@@ -77,7 +77,11 @@ void fprintf_last(FILE *file,const char *format, ...);
 
 #endif
 
-void fprintf_elapsed_time(FILE *file,struct timeval *start);
+void log_malloc(void *address,size_t size);
+void log_free(void *address);
+
+void log_mmap(size_t size);
+void log_munmap(size_t size);
 
 
 /* Error logging functions in logerror.c */
