@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2014 Andrew M. Bishop
+ This file Copyright 2008-2015 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -71,7 +71,7 @@ struct _Nodes
 
 #if !SLIM
 
- void     *data;                /*+ The memory mapped data in the file. +*/
+ char     *data;                /*+ The memory mapped data in the file. +*/
 
  index_t  *offsets;             /*+ A pointer to the array of offsets in the file. +*/
 
@@ -83,7 +83,7 @@ struct _Nodes
 
  index_t  *offsets;             /*+ An allocated array with a copy of the file offsets. +*/
 
- off_t     nodesoffset;         /*+ The offset of the nodes within the file. +*/
+ offset_t  nodesoffset;         /*+ The offset of the nodes within the file. +*/
 
  Node      cached[6];           /*+ Some cached nodes read from the file in slim mode. +*/
 
@@ -140,10 +140,12 @@ CACHE_DELETECACHE_PROTO(Node)
 CACHE_FETCHCACHE_PROTO(Node)
 CACHE_INVALIDATECACHE_PROTO(Node)
 
+/* Data type */
+
+CACHE_STRUCTURE(Node)
 
 /* Inline functions */
 
-CACHE_STRUCTURE(Node)
 CACHE_NEWCACHE(Node)
 CACHE_DELETECACHE(Node)
 CACHE_FETCHCACHE(Node)
