@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2013 Andrew M. Bishop
+ This file Copyright 2008-2015 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -43,7 +43,7 @@ extern char *option_tmpdirname;
 
 /* Local variables */
 
-/*+ Temporary file-local variables for use by the sort functions. +*/
+/*+ Temporary file-local variables for use by the sort functions (re-initialised for each sort). +*/
 static NodesX *sortnodesx;
 static latlong_t lat_min,lat_max,lon_min,lon_max;
 
@@ -76,7 +76,7 @@ NodesX *NewNodeList(int append,int readonly)
  logassert(nodesx,"Failed to allocate memory (try using slim mode?)"); /* Check calloc() worked */
 
  nodesx->filename    =(char*)malloc(strlen(option_tmpdirname)+32);
- nodesx->filename_tmp=(char*)malloc(strlen(option_tmpdirname)+32);
+ nodesx->filename_tmp=(char*)malloc(strlen(option_tmpdirname)+40); /* allow %p to be up to 20 bytes */
 
  sprintf(nodesx->filename    ,"%s/nodesx.parsed.mem",option_tmpdirname);
  sprintf(nodesx->filename_tmp,"%s/nodesx.%p.tmp"    ,option_tmpdirname,(void*)nodesx);
@@ -84,7 +84,7 @@ NodesX *NewNodeList(int append,int readonly)
  if(append || readonly)
     if(ExistsFile(nodesx->filename))
       {
-       off_t size;
+       offset_t size;
 
        size=SizeFile(nodesx->filename);
 
@@ -102,6 +102,7 @@ NodesX *NewNodeList(int append,int readonly)
 
 #if SLIM
  nodesx->cache=NewNodeXCache();
+ log_malloc(nodesx->cache,sizeof(*nodesx->cache));
 #endif
 
  return(nodesx);
@@ -127,18 +128,31 @@ void FreeNodeList(NodesX *nodesx,int keep)
  free(nodesx->filename_tmp);
 
  if(nodesx->idata)
+   {
+    log_free(nodesx->idata);
     free(nodesx->idata);
+   }
 
  if(nodesx->gdata)
+   {
+    log_free(nodesx->gdata);
     free(nodesx->gdata);
+   }
 
  if(nodesx->pdata)
+   {
+    log_free(nodesx->pdata);
     free(nodesx->pdata);
+   }
 
  if(nodesx->super)
+   {
+    log_free(nodesx->super);
     free(nodesx->super);
+   }
 
 #if SLIM
+ log_free(nodesx->cache);
  DeleteNodeXCache(nodesx->cache);
 #endif
 
@@ -269,15 +283,12 @@ void SortNodeList(NodesX *nodesx)
 
  /* Re-open the file read-only and a new file writeable */
 
- nodesx->fd=ReOpenFileBuffered(nodesx->filename_tmp);
-
- DeleteFile(nodesx->filename_tmp);
-
- fd=OpenFileBufferedNew(nodesx->filename_tmp);
+ fd=ReplaceFileBuffered(nodesx->filename_tmp,&nodesx->fd);
 
  /* Allocate the array of indexes */
 
  nodesx->idata=(node_t*)malloc(nodesx->number*sizeof(node_t));
+ log_malloc(nodesx->idata,nodesx->number*sizeof(node_t));
 
  logassert(nodesx->idata,"Failed to allocate memory (try using slim mode?)"); /* Check malloc() worked */
 
@@ -340,9 +351,9 @@ static int sort_by_id(NodeX *a,NodeX *b)
 
 static int deduplicate_and_index_by_id(NodeX *nodex,index_t index)
 {
- static node_t previd=NO_NODE_ID;
+ static node_t previd; /* internal variable (reset by first call in each sort; index==0) */
 
- if(nodex->id!=previd)
+ if(index==0 || nodex->id!=previd)
    {
     previd=nodex->id;
 
@@ -379,11 +390,12 @@ void RemoveNonHighwayNodes(NodesX *nodesx,WaysX *waysx,int keep)
 
  /* Print the start message */
 
- printf_first("Checking Ways for unused Nodes: Ways=0");
+ printf_first("Checking Ways for unused Nodes: Ways=0 Highway Nodes=0");
 
  /* Allocate the node usage bitmask */
 
  usednode=AllocBitMask(nodesx->number);
+ log_malloc(usednode,LengthBitMask(nodesx->number)*sizeof(BitMask));
 
  logassert(usednode,"Failed to allocate memory (try using slim mode?)"); /* Check AllocBitMask() worked */
 
@@ -410,7 +422,12 @@ void RemoveNonHighwayNodes(NodesX *nodesx,WaysX *waysx,int keep)
        waysize-=sizeof(node_t);
 
        if(index!=NO_NODE)
+         {
+          if(!IsBitSet(usednode,index))
+             highway++;
+
           SetBit(usednode,index);
+         }
       }
 
     waysize-=sizeof(node_t)+sizeof(WayX);
@@ -418,32 +435,49 @@ void RemoveNonHighwayNodes(NodesX *nodesx,WaysX *waysx,int keep)
     SkipFileBuffered(waysx->fd,waysize);
 
     if(!((i+1)%1000))
-       printf_middle("Checking Ways for unused Nodes: Ways=%"Pindex_t,i+1);
+       printf_middle("Checking Ways for unused Nodes: Ways=%"Pindex_t" Highway Nodes=%"Pindex_t,i+1,highway);
    }
 
+ /* Free the now-unneeded index */
+
+ log_free(nodesx->idata);
+ free(nodesx->idata);
+ nodesx->idata=NULL;
+
  /* Close the file */
 
  waysx->fd=CloseFileBuffered(waysx->fd);
 
  /* Print the final message */
 
- printf_last("Checked Ways for unused Nodes: Ways=%"Pindex_t,waysx->number);
+ printf_last("Checked Ways for unused Nodes: Ways=%"Pindex_t" Highway Nodes=%"Pindex_t,waysx->number,highway);
 
 
  /* Print the start message */
 
  printf_first("Removing unused Nodes: Nodes=0");
 
+ /* Allocate the array of indexes */
+
+ nodesx->idata=(node_t*)malloc(highway*sizeof(node_t));
+ log_malloc(nodesx->idata,highway*sizeof(node_t));
+
+ logassert(nodesx->idata,"Failed to allocate memory (try using slim mode?)"); /* Check malloc() worked */
+
+ highway=0;
+
  /* Re-open the file read-only and a new file writeable */
 
- nodesx->fd=ReOpenFileBuffered(nodesx->filename_tmp);
-
  if(keep)
+   {
     RenameFile(nodesx->filename_tmp,nodesx->filename);
- else
-    DeleteFile(nodesx->filename_tmp);
 
- fd=OpenFileBufferedNew(nodesx->filename_tmp);
+    nodesx->fd=ReOpenFileBuffered(nodesx->filename);
+
+    fd=OpenFileBufferedNew(nodesx->filename_tmp);
+   }
+ else
+    fd=ReplaceFileBuffered(nodesx->filename_tmp,&nodesx->fd);
 
  /* Modify the on-disk image */
 
@@ -475,6 +509,7 @@ void RemoveNonHighwayNodes(NodesX *nodesx,WaysX *waysx,int keep)
 
  /* Free the now-unneeded index */
 
+ log_free(usednode);
  free(usednode);
 
  /* Print the final message */
@@ -507,16 +542,13 @@ void RemovePrunedNodes(NodesX *nodesx,SegmentsX *segmentsx)
  /* Allocate the array of indexes */
 
  nodesx->pdata=(index_t*)malloc(nodesx->number*sizeof(index_t));
+ log_malloc(nodesx->pdata,nodesx->number*sizeof(index_t));
 
  logassert(nodesx->pdata,"Failed to allocate memory (try using slim mode?)"); /* Check malloc() worked */
 
  /* Re-open the file read-only and a new file writeable */
 
- nodesx->fd=ReOpenFileBuffered(nodesx->filename_tmp);
-
- DeleteFile(nodesx->filename_tmp);
-
- fd=OpenFileBufferedNew(nodesx->filename_tmp);
+ fd=ReplaceFileBuffered(nodesx->filename_tmp,&nodesx->fd);
 
  /* Modify the on-disk image */
 
@@ -550,6 +582,15 @@ void RemovePrunedNodes(NodesX *nodesx,SegmentsX *segmentsx)
  nodesx->fd=CloseFileBuffered(nodesx->fd);
  CloseFileBuffered(fd);
 
+ /* Free the no-longer required memory */
+
+ if(segmentsx->firstnode)
+   {
+    log_free(segmentsx->firstnode);
+    free(segmentsx->firstnode);
+    segmentsx->firstnode=NULL;
+   }
+
  /* Print the final message */
 
  printf_last("Deleted Pruned Nodes: Nodes=%"Pindex_t" Pruned=%"Pindex_t,total,pruned);
@@ -584,16 +625,13 @@ void SortNodeListGeographically(NodesX *nodesx)
  /* Allocate the memory for the geographical index array */
 
  nodesx->gdata=(index_t*)malloc(nodesx->number*sizeof(index_t));
+ log_malloc(nodesx->gdata,nodesx->number*sizeof(index_t));
 
  logassert(nodesx->gdata,"Failed to allocate memory (try using slim mode?)"); /* Check malloc() worked */
 
  /* Re-open the file read-only and a new file writeable */
 
- nodesx->fd=ReOpenFileBuffered(nodesx->filename_tmp);
-
- DeleteFile(nodesx->filename_tmp);
-
- fd=OpenFileBufferedNew(nodesx->filename_tmp);
+ fd=ReplaceFileBuffered(nodesx->filename_tmp,&nodesx->fd);
 
  /* Sort nodes geographically and index them */
 
@@ -608,23 +646,30 @@ void SortNodeListGeographically(NodesX *nodesx)
  nodesx->fd=CloseFileBuffered(nodesx->fd);
  CloseFileBuffered(fd);
 
- /* Free the memory */
-
- free(nodesx->super);
- nodesx->super=NULL;
-
  /* Work out the number of bins */
 
- lat_min_bin=latlong_to_bin(lat_min);
- lon_min_bin=latlong_to_bin(lon_min);
- lat_max_bin=latlong_to_bin(lat_max);
- lon_max_bin=latlong_to_bin(lon_max);
+ if(nodesx->super)
+   {
+    lat_min_bin=latlong_to_bin(lat_min);
+    lon_min_bin=latlong_to_bin(lon_min);
+    lat_max_bin=latlong_to_bin(lat_max);
+    lon_max_bin=latlong_to_bin(lon_max);
 
- nodesx->latzero=lat_min_bin;
- nodesx->lonzero=lon_min_bin;
+    nodesx->latzero=lat_min_bin;
+    nodesx->lonzero=lon_min_bin;
 
- nodesx->latbins=(lat_max_bin-lat_min_bin)+1;
- nodesx->lonbins=(lon_max_bin-lon_min_bin)+1;
+    nodesx->latbins=(lat_max_bin-lat_min_bin)+1;
+    nodesx->lonbins=(lon_max_bin-lon_min_bin)+1;
+   }
+
+ /* Free the memory */
+
+ if(nodesx->super)
+   {
+    log_free(nodesx->super);
+    free(nodesx->super);
+    nodesx->super=NULL;
+   }
 
  /* Print the final message */
 
@@ -646,7 +691,7 @@ static int update_id(NodeX *nodex,index_t index)
 {
  nodex->id=index;
 
- if(IsBitSet(sortnodesx->super,index))
+ if(sortnodesx->super && IsBitSet(sortnodesx->super,index))
     nodex->flags|=NODE_SUPER;
 
  return(1);
@@ -717,14 +762,17 @@ static int index_by_lat_long(NodeX *nodex,index_t index)
 {
  sortnodesx->gdata[nodex->id]=index;
 
- if(nodex->latitude<lat_min)
-    lat_min=nodex->latitude;
- if(nodex->latitude>lat_max)
-    lat_max=nodex->latitude;
- if(nodex->longitude<lon_min)
-    lon_min=nodex->longitude;
- if(nodex->longitude>lon_max)
-    lon_max=nodex->longitude;
+ if(sortnodesx->super)
+   {
+    if(nodex->latitude<lat_min)
+       lat_min=nodex->latitude;
+    if(nodex->latitude>lat_max)
+       lat_max=nodex->latitude;
+    if(nodex->longitude<lon_min)
+       lon_min=nodex->longitude;
+    if(nodex->longitude>lon_max)
+       lon_max=nodex->longitude;
+   }
 
  return(1);
 }
@@ -840,6 +888,12 @@ void SaveNodeList(NodesX *nodesx,const char *filename,SegmentsX *segmentsx)
 
  CloseFileBuffered(fd);
 
+ /* Free the memory in the segments */
+
+ log_free(segmentsx->firstnode);
+ free(segmentsx->firstnode);
+ segmentsx->firstnode=NULL;
+
  /* Print the final message */
 
  printf_last("Wrote Nodes: Nodes=%"Pindex_t,nodesx->number);
