@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2015 Andrew M. Bishop
+ This file Copyright 2008-2016 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -31,6 +31,7 @@
 #include "nodes.h"
 #include "segments.h"
 #include "ways.h"
+#include "relations.h"
 
 #include "functions.h"
 #include "fakes.h"
@@ -97,12 +98,14 @@ static const char junction_other_way[Highway_Count][Highway_Count]=
 
   Ways *ways The set of ways to use.
 
+  Relations *relations The set of relations to use.
+
   Profile *profile The profile containing the transport type, speeds and allowed highways.
 
   Translation *translation The set of translated strings.
   ++++++++++++++++++++++++++++++++++++++*/
 
-Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments *segments,Ways *ways,Profile *profile,Translation *translation)
+Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments *segments,Ways *ways,Relations *relations,Profile *profile,Translation *translation)
 {
  FILE                          *htmlfile=NULL,*gpxtrackfile=NULL,*gpxroutefile=NULL,*textfile=NULL,*textallfile=NULL;
  Routino_Output *listhead=NULL,*htmllist=NULL,                                      *textlist=NULL,*textalllist=NULL,*htmlalllist=NULL;
@@ -113,7 +116,6 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
  duration_t cum_duration=0;
 
  int point=0;
- int segment_count=0,route_count=0;
  int point_count=0;
  int roundabout=0;
 
@@ -581,6 +583,14 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
                      }
                   }
 
+                if(profile->turns && IsSuperNode(resultnodep) && IsTurnRestrictedNode(resultnodep))
+                  {
+                   index_t turnrelation=FindFirstTurnRelation2(relations,result->node,realsegment);
+
+                   if(turnrelation!=NO_RELATION && !IsTurnAllowed(relations,turnrelation,result->node,realsegment,seg,profile->allow))
+                      cango=0;
+                  }
+
                 if(cango)
                   {
                    Way *wayp=LookupWay(ways,segmentp->way,3);
@@ -664,7 +674,12 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
              char *type;
 
              if(important==ROUTINO_POINT_WAYPOINT)
-                type=translation->html_waypoint;
+               {
+                type=malloc(sizeof("<span class='w'>")+strlen(translation->html_waypoint)+1+4+sizeof("</span>")+1);
+
+                sprintf(type,"<span class='w'>%s#%d</span>",translation->html_waypoint,
+                                     (point_count==0?results[point]->start_waypoint:results[point]->finish_waypoint));
+               }
              else if(important==ROUTINO_POINT_MINI_RB)
                 type=translation->html_roundabout;
              else
@@ -689,7 +704,7 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
                {
                 /* <tr class='n'><td>Start at <span class='w'>Waypoint</span>, head <span class='b'>*heading*</span> */
                 fprintf(htmlfile,translation->html_start,
-                                 translation->html_waypoint,
+                                 type,
                                  next_bearing);
                }
              else if(next_result) /* middle point */
@@ -704,7 +719,7 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
                   }
                 else
                   {
-                   /* <tr class='n'><td>At junction, go <span class='t'>*direction*</span> heading <span class='b'>*heading*</span> */
+                   /* <tr class='n'><td>At *waypoint/roundabout/junction*, go <span class='t'>*direction*</span> heading <span class='b'>*heading*</span> */
                    fprintf(htmlfile,translation->html_node,
                                     type,
                                     turn,
@@ -715,12 +730,15 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
                {
                 /* <tr class='n'><td>Stop at <span class='w'>Waypoint</span> */
                 fprintf(htmlfile,translation->html_stop,
-                                 translation->html_waypoint);
+                                 type);
 
                 /* <tr class='t'><td><span class='j'>Total *distance* km, *time* minutes</span> */
                 fprintf(htmlfile,translation->html_total,
                                  distance_to_km(cum_distance),duration_to_minutes(cum_duration));
                }
+
+             if(important==ROUTINO_POINT_WAYPOINT)
+                free(type);
             }
 
           if(htmllist)
@@ -729,7 +747,12 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
              char *type;
 
              if(important==ROUTINO_POINT_WAYPOINT)
-                type=translation->nothtml_waypoint;
+               {
+                type=malloc(strlen(translation->nothtml_waypoint)+1+4+1);
+
+                sprintf(type,"%s#%d",translation->nothtml_waypoint,
+                                     (point_count==0?results[point]->start_waypoint:results[point]->finish_waypoint));
+               }
              else if(important==ROUTINO_POINT_MINI_RB)
                 type=translation->nothtml_roundabout;
              else
@@ -775,12 +798,12 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
                {
                 /* Start: At Waypoint, head *heading* */
                 strl=strlen(translation->nothtml_start)+
-                     strlen(translation->nothtml_waypoint)+strlen(next_bearingraw)+1;
+                     strlen(type)+strlen(next_bearingraw)+1;
 
                 htmllist->desc1=malloc(strl);
 
                 sprintf(htmllist->desc1,translation->nothtml_start,
-                                        translation->nothtml_waypoint,
+                                        type,
                                         next_bearingraw);
 
                 htmllist->name=strcpy(malloc(strlen(next_waynameraw)+1),next_waynameraw);
@@ -802,7 +825,7 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
                   }
                 else
                   {
-                   /* At: Junction, go *direction* heading *heading* */
+                   /* At: Waypoint/Roundabout/Junction, go *direction* heading *heading* */
                    strl=strlen(translation->nothtml_node)+
                         strlen(type)+strlen(turnraw)+strlen(next_bearingraw)+1;
 
@@ -821,12 +844,12 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
                {
                 /* Stop: At Waypoint */
                 strl=strlen(translation->nothtml_stop)+
-                     strlen(translation->nothtml_waypoint)+1;
+                     strlen(type)+1;
 
                 htmllist->desc1=malloc(strl);
 
                 sprintf(htmllist->desc1,translation->nothtml_stop,
-                                        translation->nothtml_waypoint);
+                                        type);
 
                 /* Total: *distance* km, *time* minutes */
                 strl=strlen(translation->nothtml_total)+8+8+1;
@@ -840,6 +863,9 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
                }
 
              htmllist->bearing=next_bearing_int;
+
+             if(important==ROUTINO_POINT_WAYPOINT)
+                free(type);
             }
 
           if(gpxroutefile)
@@ -856,15 +882,15 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
 
              if(point_count==0) /* first point */
                {
-                fprintf(gpxroutefile,"<rtept lat=\"%.6f\" lon=\"%.6f\"><name>%s</name>\n",
+                fprintf(gpxroutefile,"<rtept lat=\"%.6f\" lon=\"%.6f\"><name>%s%02d</name>\n",
                                      radians_to_degrees(latitude),radians_to_degrees(longitude),
-                                     translation->gpx_start);
+                                     translation->gpx_waypt,results[point]->start_waypoint);
                }
              else if(!next_result) /* end point */
                {
-                fprintf(gpxroutefile,"<rtept lat=\"%.6f\" lon=\"%.6f\"><name>%s</name>\n",
+                fprintf(gpxroutefile,"<rtept lat=\"%.6f\" lon=\"%.6f\"><name>%s%02d</name>\n",
                                      radians_to_degrees(latitude),radians_to_degrees(longitude),
-                                     translation->gpx_finish);
+                                     translation->gpx_waypt,results[point]->finish_waypoint);
                 fprintf(gpxroutefile,"<desc>");
                 fprintf(gpxroutefile,translation->gpx_final,
                                      distance_to_km(cum_distance),duration_to_minutes(cum_duration));
@@ -873,13 +899,13 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
              else            /* middle point */
                {
                 if(important==ROUTINO_POINT_WAYPOINT)
-                   fprintf(gpxroutefile,"<rtept lat=\"%.6f\" lon=\"%.6f\"><name>%s%d</name>\n",
+                   fprintf(gpxroutefile,"<rtept lat=\"%.6f\" lon=\"%.6f\"><name>%s%02d</name>\n",
                                         radians_to_degrees(latitude),radians_to_degrees(longitude),
-                                        translation->gpx_inter,++segment_count);
+                                        translation->gpx_waypt,results[point]->finish_waypoint);
                 else
                    fprintf(gpxroutefile,"<rtept lat=\"%.6f\" lon=\"%.6f\"><name>%s%03d</name>\n",
                                         radians_to_degrees(latitude),radians_to_degrees(longitude),
-                                        translation->gpx_trip,++route_count);
+                                        translation->gpx_trip,point_count);
                }
             }
 
@@ -888,7 +914,13 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
              char *type;
 
              if(important==ROUTINO_POINT_WAYPOINT)
-                type="Waypt";
+               {
+                type=malloc(sizeof("Waypt")+1+4+1);
+
+                sprintf(type,"Waypt#%d",(point_count==0?results[point]->start_waypoint:results[point]->finish_waypoint));
+               }
+             else if(important==ROUTINO_POINT_MINI_RB)
+                type="Mini-RB";
              else
                 type="Junct";
 
@@ -920,6 +952,9 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
                                  ((22+next_bearing_int)/45+4)%8-4,
                                  next_waynameraw);
                }
+
+             if(important==ROUTINO_POINT_WAYPOINT)
+                free(type);
             }
 
           if(textlist)
@@ -1014,7 +1049,11 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
              char *type;
 
              if(important==ROUTINO_POINT_WAYPOINT)
-                type="Waypt";
+               {
+                type=malloc(sizeof("Waypt")+1+4+1);
+
+                sprintf(type,"Waypt#%d",(point_count==0?results[point]->start_waypoint:results[point]->finish_waypoint));
+               }
              else if(important==ROUTINO_POINT_UTURN)
                 type="U-turn";
              else if(important==ROUTINO_POINT_MINI_RB)
@@ -1048,6 +1087,9 @@ Routino_Output *PrintRoute(Results **results,int nresults,Nodes *nodes,Segments
                                     bearing_int,
                                     waynameraw);
                }
+
+             if(important==ROUTINO_POINT_WAYPOINT)
+                free(type);
             }
 
           if(textalllist)
