@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2014 Andrew M. Bishop
+ This file Copyright 2008-2015 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -30,8 +30,11 @@
 
 /* Constants */
 
+/* A fake result pointer. */
+#define NO_RESULT ((Result*)~0)
+
 /*+ A result is not currently queued. +*/
-#define NOT_QUEUED (uint32_t)(0)
+#define NOT_QUEUED ((uint32_t)0)
 
 
 /* Data structures */
