@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2014 Andrew M. Bishop
+ This file Copyright 2008-2015 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -492,8 +492,8 @@ SegmentsX *MergeSuperSegments(SegmentsX *segmentsx,SegmentsX *supersegmentsx)
 
 static Results *FindSuperRoutes(NodesX *nodesx,SegmentsX *segmentsx,WaysX *waysx,node_t start,Way *match)
 {
- static Results *results=NULL;
- static Queue *queue=NULL;
+ static Results *results=NULL; /* static allocation of return value (reset each call) */
+ static Queue *queue=NULL;     /* static allocation of internal value (reset each call) */
  Result *result1,*result2;
  WayX *wayx;
 
