@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2014 Andrew M. Bishop
+ This file Copyright 2008-2015 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -31,12 +31,11 @@
 #include "relations.h"
 #include "errorlog.h"
 
+#include "typesx.h"
+
 #include "visualiser.h"
 
 
-/*+ The maximum number of segments per node (used to size temporary storage). +*/
-#define MAX_SEG_PER_NODE 32
-
 /* Limit types */
 
 #define SPEED_LIMIT  1
@@ -49,7 +48,7 @@
 
 typedef void (*callback_t)(index_t node,double latitude,double longitude);
 
-/* Local variables */
+/* Local variables (intialised by entry-point function before later use) */
 
 static Nodes     *OSMNodes;
 static Segments  *OSMSegments;
