@@ -3,7 +3,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2008-2014 Andrew M. Bishop
+ This file Copyright 2008-2015 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -72,16 +72,16 @@ struct _WaysX
 
 #endif
 
- way_t   *idata;                /*+ The extended way IDs (sorted by ID). +*/
- off_t   *odata;                /*+ The offset of the way in the file (used for error log). +*/
+ way_t    *idata;               /*+ The extended way IDs (sorted by ID). +*/
+ offset_t *odata;               /*+ The offset of the way in the file (used for error log). +*/
 
- index_t *cdata;                /*+ The compacted way IDs (same order as sorted ways). +*/
+ index_t  *cdata;               /*+ The compacted way IDs (same order as sorted ways). +*/
 
- char    *nfilename_tmp;        /*+ The name of the temporary file (for the WaysX names). +*/
+ char     *nfilename_tmp;       /*+ The name of the temporary file (for the WaysX names). +*/
 
- int      nfd;                  /*+ The file descriptor of the temporary file (for the WaysX names). +*/
+ int       nfd;                 /*+ The file descriptor of the temporary file (for the WaysX names). +*/
 
- uint32_t nlength;              /*+ The length of the string of name entries. +*/
+ uint32_t  nlength;             /*+ The length of the string of name entries. +*/
 };
 
 
@@ -129,10 +129,12 @@ CACHE_FETCHCACHE_PROTO(WayX)
 CACHE_REPLACECACHE_PROTO(WayX)
 CACHE_INVALIDATECACHE_PROTO(WayX)
 
+/* Data type */
+
+CACHE_STRUCTURE(WayX)
 
 /* Inline functions */
 
-CACHE_STRUCTURE(WayX)
 CACHE_NEWCACHE(WayX)
 CACHE_DELETECACHE(WayX)
 CACHE_FETCHCACHE(WayX)
