@@ -5,7 +5,7 @@
 
  Part of the Routino routing software.
  ******************/ /******************
- This file Copyright 2010-2012 Andrew M. Bishop
+ This file Copyright 2010-2015 Andrew M. Bishop
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Affero General Public License as published by
@@ -23,7 +23,9 @@
 
 
 #include <stdio.h>
+#if !defined(_MSC_VER)
 #include <unistd.h>
+#endif
 #include <ctype.h>
 #include <stdlib.h>
 #include <string.h>
@@ -70,56 +72,56 @@ static int attributeType_function(const char *_tag_,int _type_,const char *name,
 
 /* The XML tag definitions (forward declarations) */
 
-static xmltag xmlDeclaration_tag;
-static xmltag schemaType_tag;
-static xmltag elementType_tag;
-static xmltag complexType_tag;
-static xmltag sequenceType_tag;
-static xmltag attributeType_tag;
+static const xmltag xmlDeclaration_tag;
+static const xmltag schemaType_tag;
+static const xmltag elementType_tag;
+static const xmltag complexType_tag;
+static const xmltag sequenceType_tag;
+static const xmltag attributeType_tag;
 
 
 /* The XML tag definition values */
 
 /*+ The complete set of tags at the top level. +*/
-static xmltag *xml_toplevel_tags[]={&xmlDeclaration_tag,&schemaType_tag,NULL};
+static const xmltag * const xml_toplevel_tags[]={&xmlDeclaration_tag,&schemaType_tag,NULL};
 
 /*+ The xmlDeclaration type tag. +*/
-static xmltag xmlDeclaration_tag=
+static const xmltag xmlDeclaration_tag=
               {"xml",
                2, {"version","encoding"},
                xmlDeclaration_function,
                {NULL}};
 
 /*+ The schemaType type tag. +*/
-static xmltag schemaType_tag=
+static const xmltag schemaType_tag=
               {"xsd:schema",
                2, {"elementFormDefault","xmlns:xsd"},
                schemaType_function,
                {&elementType_tag,&complexType_tag,NULL}};
 
 /*+ The elementType type tag. +*/
-static xmltag elementType_tag=
+static const xmltag elementType_tag=
               {"xsd:element",
                4, {"name","type","minOccurs","maxOccurs"},
                elementType_function,
                {NULL}};
 
 /*+ The complexType type tag. +*/
-static xmltag complexType_tag=
+static const xmltag complexType_tag=
               {"xsd:complexType",
                1, {"name"},
                complexType_function,
                {&sequenceType_tag,&attributeType_tag,NULL}};
 
 /*+ The sequenceType type tag. +*/
-static xmltag sequenceType_tag=
+static const xmltag sequenceType_tag=
               {"xsd:sequence",
                0, {NULL},
                sequenceType_function,
                {&elementType_tag,NULL}};
 
 /*+ The attributeType type tag. +*/
-static xmltag attributeType_tag=
+static const xmltag attributeType_tag=
               {"xsd:attribute",
                2, {"name","type"},
                attributeType_function,
@@ -338,7 +340,9 @@ int main(int argc,char **argv)
  printf("\n");
  printf("\n");
  printf("#include <stdio.h>\n");
+ printf("#if !defined(_MSC_VER)\n");
  printf("#include <unistd.h>\n");
+ printf("#endif\n");
  printf("\n");
  printf("#include \"xmlparse.h\"\n");
 
@@ -368,7 +372,7 @@ int main(int argc,char **argv)
  printf("\n");
 
  for(i=0;i<ntagsx;i++)
-    printf("static xmltag %s_tag;\n",safe(tagsx[i]->type));
+    printf("static const xmltag %s_tag;\n",safe(tagsx[i]->type));
 
  printf("\n");
  printf("\n");
@@ -376,7 +380,7 @@ int main(int argc,char **argv)
 
  printf("\n");
  printf("/*+ The complete set of tags at the top level. +*/\n");
- printf("static xmltag *xml_toplevel_tags[]={");
+ printf("static const xmltag * const xml_toplevel_tags[]={");
  printf("&%s_tag,",safe(tagsx[0]->type));
  printf("&%s_tag,",safe(tagsx[1]->type));
  printf("NULL};\n");
@@ -385,7 +389,7 @@ int main(int argc,char **argv)
    {
     printf("\n");
     printf("/*+ The %s type tag. +*/\n",tagsx[i]->type);
-    printf("static xmltag %s_tag=\n",safe(tagsx[i]->type));
+    printf("static const xmltag %s_tag=\n",safe(tagsx[i]->type));
     printf("              {\"%s\",\n",tagsx[i]->name);
 
     printf("               %d, {",tagsx[i]->nattributes);
@@ -494,7 +498,7 @@ int main(int argc,char **argv)
 
 static char *safe(const char *name)
 {
- static char *safe=NULL;
+ static char *safe=NULL; /* static allocation of return value */
  int i;
 
  safe=realloc(safe,strlen(name)+1);
