@@ -13,7 +13,7 @@ Routino router web page.
 
 Part of the Routino routing software.
 
-This file Copyright 2008-2018 Andrew M. Bishop
+This file Copyright 2008-2017 Andrew M. Bishop
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
@@ -85,34 +85,18 @@ Select start and end points (click on the marker icons below), select routing pr
 <td>(EN)
 <td><input name="language" type="radio" value="en" onchange="formSetLanguage();" >
 <tr>
-<td><a id="lang_cs_url" href="router.html.cs" title="Stránka v češtině">Česky</a>
-<td>(CS)
-<td><input name="language" type="radio" value="cs" onchange="formSetLanguage();" >
-<tr>
 <td><a id="lang_de_url" href="router.html.de" title="Deutsche Webseite">Deutsch</a>
 <td>(DE)
 <td><input name="language" type="radio" value="de" onchange="formSetLanguage();" >
 <tr>
-<td><a id="lang_es_url" href="router.html.es" title="Español webpage">Español</a>
-<td>(ES)
-<td><input name="language" type="radio" value="es" onchange="formSetLanguage();" >
-<tr>
-<td><a id="lang_fi_url" href="router.html.fi" title="Suomi webpage">Suomi</a>
-<td>(FI)
-<td><input name="language" type="radio" value="fi" onchange="formSetLanguage();" >
-<tr>
 <td><a id="lang_fr_url" href="router.html.fr" title="Page web en français">Français</a>
 <td>(FR)
 <td><input name="language" type="radio" value="fr" onchange="formSetLanguage();" >
 <tr>
-<td><a id="lang_hu_url" href="router.html.hu" title="Magyar weboldal">Magyar</a>
+<td><a id="lang_hu_url" href="router.html.hu" title="Magyar weblap">Magyar</a>
 <td>(HU)
 <td><input name="language" type="radio" value="hu" onchange="formSetLanguage();" >
 <tr>
-<td><a id="lang_it_url" href="router.html.it" title="Italiano webpage">Italiano</a>
-<td>(IT)
-<td><input name="language" type="radio" value="it" onchange="formSetLanguage();" >
-<tr>
 <td><a id="lang_nl_url" href="router.html.nl" title="Nederlandse web pagina">Nederlands</a>
 <td>(NL)
 <td><input name="language" type="radio" value="nl" onchange="formSetLanguage();" >
@@ -121,13 +105,9 @@ Select start and end points (click on the marker icons below), select routing pr
 <td>(PL)
 <td><input name="language" type="radio" value="pl" onchange="formSetLanguage();" checked>
 <tr>
-<td><a id="lang_ru_url" href="router.html.ru" title="Страница на русском языке">Русский</a>
+<td><a id="lang_ru_url" href="router.html.ru" title="Страница на Русском языке">Русский</a>
 <td>(RU)
 <td><input name="language" type="radio" value="ru" onchange="formSetLanguage();" >
-<tr>
-<td><a id="lang_sk_url" href="router.html.sk" title="Stránka v slovenčine">Slovenčina</a>
-<td>(SK)
-<td><input name="language" type="radio" value="sk" onchange="formSetLanguage();" >
 </table>
 <a target="translation" href="http://www.routino.org/translations/">Routino Translations</a>
 </div>
@@ -140,13 +120,13 @@ Select start and end points (click on the marker icons below), select routing pr
 <div id="hideshow_waypoint_div">
 <div id="waypoints">
 <div id="waypointXXX" class="waypoint" style="display: none;">
-<img id="iconXXX" class="waypoint-icon" src="icons/marker-XXX-grey.png" title="Punkt XXX trasy" alt="Waypoint XXX" onmouseup="markerToggleMap(XXX);" draggable="true">
-<span id="coordsXXX" style="display: none;">
-<input name="lonXXX" type="text" size="6" title="Punkt XXX długości geograficznej" onchange="formSetCoords(XXX);">E
-<input name="latXXX" type="text" size="7" title="Punkt XXX szerokości geograficznej" onchange="formSetCoords(XXX);">N
+<img id="iconXXX" class="waypoint-icon" src="icons/marker-XXX-grey.png" title="Waypoint XXX Position" alt="Waypoint XXX" onmouseup="markerToggleMap(XXX);" draggable="true">
+<span id="coordsXXX">
+<input name="lonXXX" type="text" size="6" title="Waypoint XXX Longitude" onchange="formSetCoords(XXX);">E
+<input name="latXXX" type="text" size="7" title="Waypoint XXX Latitude" onchange="formSetCoords(XXX);">N
 </span>
-<span id="searchXXX">
-<input name="searchXXX" type="text" size="18" title="Punkt orientacyjny XXX"> <!-- uses Javascript event for triggering -->
+<span id="searchXXX" style="display: none;">
+<input name="searchXXX" type="text" size="18" title="Waypoint XXX Location"> <!-- uses Javascript event for triggering -->
 </span>
 <div class="waypoint-buttons" style="display: inline-block;">
 <img alt="?" src="icons/waypoint-search.png" title="Znajdź miejsce" onmousedown="markerSearch(XXX);" >
@@ -158,8 +138,8 @@ Select start and end points (click on the marker icons below), select routing pr
 <img alt="#" src="icons/waypoint-coords.png" title="Współrzędne dla lokalizacji" onmousedown="markerCoords(XXX);" >
 <img alt="~" src="icons/waypoint-home.png" title="Współrzędne lokalizacji" onmousedown="markerHome(XXX);" >
 <img alt="o" src="icons/waypoint-centre.png" title="Wyśrodkuj ten punkt na mapie" onmousedown="markerCentre(XXX);" >
-<img alt="v" src="icons/waypoint-down.png" title="Przesuń punkt na dół" onmousedown="markerMoveDown(XXX);">
-<img alt="-" src="icons/waypoint-remove.png" title="Usuń punkt" onmousedown="markerRemove(XXX);" >
+<img alt="v" src="icons/waypoint-down.png" title="Move this waypoint down" onmousedown="markerMoveDown(XXX);">
+<img alt="-" src="icons/waypoint-remove.png" title="Remove this waypoint" onmousedown="markerRemove(XXX);" >
 </div>
 <div id="searchresultsXXX" style="display: none;">
 </div>
@@ -167,12 +147,12 @@ Select start and end points (click on the marker icons below), select routing pr
 </div>
 <div id="waypoints-buttons">
 <table>
-<tr><td>Zamknij pętlę: <td><input type="checkbox" name="loop" onchange="formSetLoopReverse('loop' );">
-<tr><td>Odwrotna kolejność:<td><input type="checkbox" name="reverse" onchange="formSetLoopReverse('reverse');">
+<tr><td>Close loop: <td><input type="checkbox" name="loop" onchange="formSetLoopReverse('loop' );">
+<tr><td>Reverse order:<td><input type="checkbox" name="reverse" onchange="formSetLoopReverse('reverse');">
 </table>
 <div class="waypoint-buttons" style="display: inline-block;">
-<img src="icons/waypoint-loop.png" title="Dodaj nowy punkt, aby zrobić pętlę" onmousedown="markersLoop();">
-<img src="icons/waypoint-reverse.png" title="Odwrotna kolejność punktów trasy" onmousedown="markersReverse();">
+<img src="icons/waypoint-loop.png" title="Add a new waypoint to make a loop" onmousedown="markersLoop();">
+<img src="icons/waypoint-reverse.png" title="Reverse order of waypoints" onmousedown="markersReverse();">
 </div>
 </div>
 </div>
@@ -197,7 +177,7 @@ Select start and end points (click on the marker icons below), select routing pr
 <tr><td>Moped: <td><input name="transport" type="radio" value="moped" onchange="formSetTransport('moped' );">
 <tr><td>Motocykl:<td><input name="transport" type="radio" value="motorcycle" onchange="formSetTransport('motorcycle');">
 <tr><td>Samochód: <td><input name="transport" type="radio" value="motorcar" onchange="formSetTransport('motorcar' );">
-<tr><td>Dobra: <td><input name="transport" type="radio" value="goods" onchange="formSetTransport('goods' );">
+<tr><td>Goods: <td><input name="transport" type="radio" value="goods" onchange="formSetTransport('goods' );">
 <tr><td>Pojazd ciężarowy: <td><input name="transport" type="radio" value="hgv" onchange="formSetTransport('hgv' );">
 <tr><td>Pojazd użyteczności publicznej: <td><input name="transport" type="radio" value="psv" onchange="formSetTransport('psv' );">
 </table>
@@ -218,10 +198,10 @@ Select start and end points (click on the marker icons below), select routing pr
 <tr><td>Niesklasyfikowana:<td><input name="highway-unclassified" type="text" size="3" onchange="formSetHighway('unclassified','=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetHighway('unclassified','-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetHighway('unclassified','+');">
 <tr><td>W obszarze zamieszkania: <td><input name="highway-residential" type="text" size="3" onchange="formSetHighway('residential' ,'=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetHighway('residential' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetHighway('residential' ,'+');">
 <tr><td>Dojazdowa: <td><input name="highway-service" type="text" size="3" onchange="formSetHighway('service' ,'=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetHighway('service' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetHighway('service' ,'+');">
-<tr><td>Ścieżka: <td><input name="highway-track" type="text" size="3" onchange="formSetHighway('track' ,'=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetHighway('track' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetHighway('track' ,'+');">
+<tr><td>Track: <td><input name="highway-track" type="text" size="3" onchange="formSetHighway('track' ,'=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetHighway('track' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetHighway('track' ,'+');">
 <tr><td>Rowerowa: <td><input name="highway-cycleway" type="text" size="3" onchange="formSetHighway('cycleway' ,'=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetHighway('cycleway' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetHighway('cycleway' ,'+');">
 <tr><td>Ścieżka: <td><input name="highway-path" type="text" size="3" onchange="formSetHighway('path' ,'=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetHighway('path' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetHighway('path' ,'+');">
-<tr><td>Kroki: <td><input name="highway-steps" type="text" size="3" onchange="formSetHighway('steps' ,'=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetHighway('steps' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetHighway('steps' ,'+');">
+<tr><td>Steps: <td><input name="highway-steps" type="text" size="3" onchange="formSetHighway('steps' ,'=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetHighway('steps' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetHighway('steps' ,'+');">
 <tr><td>Przeprawa: <td><input name="highway-ferry" type="text" size="3" onchange="formSetHighway('ferry' ,'=');"><td>%<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetHighway('ferry' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetHighway('ferry' ,'+');">
 </table>
 </div>
@@ -241,10 +221,10 @@ Select start and end points (click on the marker icons below), select routing pr
 <tr><td>Niesklasyfikowana:<td><input name="speed-unclassified" type="text" size="3" onchange="formSetSpeed('unclassified','=');"><td>km/hr<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetSpeed('unclassified','-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetSpeed('unclassified','+');">
 <tr><td>W obszarze zamieszkania: <td><input name="speed-residential" type="text" size="3" onchange="formSetSpeed('residential' ,'=');"><td>km/hr<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetSpeed('residential' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetSpeed('residential' ,'+');">
 <tr><td>Dojazdowa: <td><input name="speed-service" type="text" size="3" onchange="formSetSpeed('service' ,'=');"><td>km/hr<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetSpeed('service' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetSpeed('service' ,'+');">
-<tr><td>Ścieżka: <td><input name="speed-track" type="text" size="3" onchange="formSetSpeed('track' ,'=');"><td>km/hr<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetSpeed('track' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetSpeed('track' ,'+');">
+<tr><td>Track: <td><input name="speed-track" type="text" size="3" onchange="formSetSpeed('track' ,'=');"><td>km/hr<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetSpeed('track' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetSpeed('track' ,'+');">
 <tr><td>Rowerowa: <td><input name="speed-cycleway" type="text" size="3" onchange="formSetSpeed('cycleway' ,'=');"><td>km/hr<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetSpeed('cycleway' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetSpeed('cycleway' ,'+');">
 <tr><td>Ścieżka: <td><input name="speed-path" type="text" size="3" onchange="formSetSpeed('path' ,'=');"><td>km/hr<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetSpeed('path' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetSpeed('path' ,'+');">
-<tr><td>Kroki: <td><input name="speed-steps" type="text" size="3" onchange="formSetSpeed('steps' ,'=');"><td>km/hr<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetSpeed('steps' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetSpeed('steps' ,'+');">
+<tr><td>Steps: <td><input name="speed-steps" type="text" size="3" onchange="formSetSpeed('steps' ,'=');"><td>km/hr<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetSpeed('steps' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetSpeed('steps' ,'+');">
 <tr><td>Przeprawa: <td><input name="speed-ferry" type="text" size="3" onchange="formSetSpeed('ferry' ,'=');"><td>km/hr<td><img alt="<" src="icons/waypoint-left.png" title="-" onmousedown="formSetSpeed('ferry' ,'-');">&ndash;/+<img alt=">" src="icons/waypoint-right.png" title="+" onmousedown="formSetSpeed('ferry' ,'+');">
 </table>
 </div>
