@@ -4,7 +4,7 @@
 #
 # Part of the Routino routing software.
 #
-# This file Copyright 2011-2014 Andrew M. Bishop
+# This file Copyright 2011-2014, 2016 Andrew M. Bishop
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -23,7 +23,7 @@
 use strict;
 
 # Use the directory paths script
-require "paths.pl";
+require "./paths.pl";
 
 
 # The parameters for the execution
