@@ -13,7 +13,7 @@ Routino data visualiser web page.
 
 Part of the Routino routing software.
 
-This file Copyright 2008-2017 Andrew M. Bishop
+This file Copyright 2008-2014 Andrew M. Bishop
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
@@ -83,38 +83,23 @@ Only data relevant for routing is displayed and some will therefore be excluded.
 <td><a id="lang_en_url" href="visualiser.html.en" title="English language webpage">English</a>
 <td>(EN)
 <tr>
-<td><a id="lang_cs_url" href="visualiser.html.cs" title="Stránka v češtině">Česky</a>
-<td>(CS)
-<tr>
 <td><a id="lang_de_url" href="visualiser.html.de" title="Deutsche Webseite">Deutsch</a>
 <td>(DE)
 <tr>
-<td><a id="lang_es_url" href="visualiser.html.es" title="Español webpage">Español</a>
-<td>(ES)
-<tr>
-<td><a id="lang_fi_url" href="visualiser.html.fi" title="Suomi webpage">Suomi</a>
-<td>(FI)
-<tr>
 <td><a id="lang_fr_url" href="visualiser.html.fr" title="Page web en français">Français</a>
 <td>(FR)
 <tr>
-<td><a id="lang_hu_url" href="visualiser.html.hu" title="Magyar weboldal">Magyar</a>
+<td><a id="lang_hu_url" href="visualiser.html.hu" title="Magyar weblap">Magyar</a>
 <td>(HU)
 <tr>
-<td><a id="lang_it_url" href="visualiser.html.it" title="Italiano webpage">Italiano</a>
-<td>(IT)
-<tr>
 <td><a id="lang_nl_url" href="visualiser.html.nl" title="Nederlandse web pagina">Nederlands</a>
 <td>(NL)
 <tr>
 <td><a id="lang_pl_url" href="visualiser.html.pl" title="Polski webpage">Polski</a>
 <td>(PL)
 <tr>
-<td><a id="lang_ru_url" href="visualiser.html.ru" title="Страница на русском языке">Русский</a>
+<td><a id="lang_ru_url" href="visualiser.html.ru" title="Страница на Русском языке">Русский</a>
 <td>(RU)
-<tr>
-<td><a id="lang_sk_url" href="visualiser.html.sk" title="Stránka v slovenčine">Slovenčina</a>
-<td>(SK)
 </table>
 <a target="translation" href="http://www.routino.org/translations/">Routino Translations</a>
 </div>
@@ -235,10 +220,10 @@ Each segment of the chosen type of highway is drawn.
 <tr><td>Niesklasyfikowana:<td><input name="highway" type="radio" value="unclassified" onchange="displayData('highway');">
 <tr><td>W obszarze zamieszkania: <td><input name="highway" type="radio" value="residential" onchange="displayData('highway');">
 <tr><td>Dojazdowa: <td><input name="highway" type="radio" value="service" onchange="displayData('highway');">
-<tr><td>Ścieżka: <td><input name="highway" type="radio" value="track" onchange="displayData('highway');">
+<tr><td>Track: <td><input name="highway" type="radio" value="track" onchange="displayData('highway');">
 <tr><td>Rowerowa: <td><input name="highway" type="radio" value="cycleway" onchange="displayData('highway');">
 <tr><td>Ścieżka: <td><input name="highway" type="radio" value="path" onchange="displayData('highway');">
-<tr><td>Kroki: <td><input name="highway" type="radio" value="steps" onchange="displayData('highway');">
+<tr><td>Steps: <td><input name="highway" type="radio" value="steps" onchange="displayData('highway');">
 <tr><td>Przeprawa: <td><input name="highway" type="radio" value="ferry" onchange="displayData('highway');">
 </table>
 </form>
@@ -260,7 +245,7 @@ Each segment allowed for the chosen type of transport is drawn.
 <tr><td>Moped: <td><input name="transport" type="radio" value="moped" onchange="displayData('transport');">
 <tr><td>Motocykl:<td><input name="transport" type="radio" value="motorcycle" onchange="displayData('transport');">
 <tr><td>Samochód: <td><input name="transport" type="radio" value="motorcar" onchange="displayData('transport');" checked>
-<tr><td>Dobra: <td><input name="transport" type="radio" value="goods" onchange="displayData('transport');">
+<tr><td>Goods: <td><input name="transport" type="radio" value="goods" onchange="displayData('transport');">
 <tr><td>Pojazd ciężarowy: <td><input name="transport" type="radio" value="hgv" onchange="displayData('transport');">
 <tr><td>Pojazd użyteczności publicznej: <td><input name="transport" type="radio" value="psv" onchange="displayData('transport');">
 </table>
@@ -283,7 +268,7 @@ Each barrier blocking the chosen type of transport is drawn.
 <tr><td>Moped: <td><input name="barrier" type="radio" value="moped" onchange="displayData('barrier');">
 <tr><td>Motocykl:<td><input name="barrier" type="radio" value="motorcycle" onchange="displayData('barrier');">
 <tr><td>Samochód: <td><input name="barrier" type="radio" value="motorcar" onchange="displayData('barrier');" checked>
-<tr><td>Dobra: <td><input name="barrier" type="radio" value="goods" onchange="displayData('barrier');">
+<tr><td>Goods: <td><input name="barrier" type="radio" value="goods" onchange="displayData('barrier');">
 <tr><td>Pojazd ciężarowy: <td><input name="barrier" type="radio" value="hgv" onchange="displayData('barrier');">
 <tr><td>Pojazd użyteczności publicznej: <td><input name="barrier" type="radio" value="psv" onchange="displayData('barrier');">
 </table>
